@@ -10,11 +10,11 @@ import publication
 
 import aws_cdk.aws_ec2
 import aws_cdk.aws_logs
+import aws_cdk.cloud_assembly_schema
 import aws_cdk.core
-import aws_cdk.cx_api
 import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-route53", "1.37.0", __name__[0:-6], "aws-route53@1.37.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-route53", "1.38.0", __name__[0:-6], "aws-route53@1.38.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
